pub fn init()Expand description
init_default is the default way to call with_targets,
it sets up Level::INFO and looks for environment variables to filter spans.
pub fn init()init_default is the default way to call with_targets,
it sets up Level::INFO and looks for environment variables to filter spans.